@@ -39,6 +39,15 @@ from pythonix.internals.res import (
     UnwrapError,
     ExpectError,
     Nil,
+    catch_all,
+    convert_err,
+    err_and,
+    is_err,
+    expect_err,
+    expect,
+    is_ok,
+    unwrap_err,
+    ok_and,
     null_and_error_safe,
     combine_errors,
     safe,
